--- ExtractInterfaceRefactoringContribution.java	Wed Aug  5 23:14:29 2009
+++ ExtractSupertypeRefactoringContribution.java	Wed Aug  5 23:14:13 2009
@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2007 IBM Corporation and others.
+ * Copyright (c) 2005, 2008 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -23,29 +23,29 @@
 
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.refactoring.JavaRefactoringArguments;
-import org.eclipse.jdt.internal.corext.refactoring.structure.ExtractInterfaceProcessor;
+import org.eclipse.jdt.internal.corext.refactoring.structure.ExtractSupertypeProcessor;
 
 /**
  * Refactoring contribution for the extract interface refactoring.
  *
  * @since 3.2
  */
-public final class ExtractInterfaceRefactoringContribution extends JavaUIRefactoringContribution {
+public final class ExtractSupertypeRefactoringContribution extends JavaUIRefactoringContribution {
 
 	/**
 	 * {@inheritDoc}
 	 */
 	public final Refactoring createRefactoring(JavaRefactoringDescriptor descriptor, RefactoringStatus status) throws CoreException {
 		JavaRefactoringArguments arguments= new JavaRefactoringArguments(descriptor.getProject(), retrieveArgumentMap(descriptor));
-		ExtractInterfaceProcessor processor= new ExtractInterfaceProcessor(arguments, status);
+		ExtractSupertypeProcessor processor= new ExtractSupertypeProcessor(arguments, status);
 		return new ProcessorBasedRefactoring(processor);
 	}
 
 	public RefactoringDescriptor createDescriptor() {
-		return RefactoringSignatureDescriptorFactory.createExtractInterfaceDescriptor();
+		return RefactoringSignatureDescriptorFactory.createExtractSuperclassDescriptor();
 	}
 
 	public RefactoringDescriptor createDescriptor(String id, String project, String description, String comment, Map arguments, int flags) {
-		return RefactoringSignatureDescriptorFactory.createExtractInterfaceDescriptor(project, description, comment, arguments, flags);
+		return RefactoringSignatureDescriptorFactory.createExtractSuperclassDescriptor(project, description, comment, arguments, flags);
 	}
 }
@@ -23,29 +23,29 @@
 
 /**
- * Refactoring contribution for the extract interface refactoring.
+ * Refactoring contribution for the extract supertype refactoring.
  *
  * @since 3.2
